nio API
=======

This document details the API of nio.

Api
---

.. autoclass:: nio.Api
    :members:
    :undoc-members:

Client
-----------------

.. autoclass:: nio.Client
    :members:

AsyncClient
-----------

.. autoclass:: nio.AsyncClient
    :members:
    :undoc-members:
    :show-inheritance:


HttpClient
-----------------

.. autoclass:: nio.HttpClient
    :members:
    :undoc-members:
    :show-inheritance:

nio.events module
-----------------

.. automodule:: nio.events
    :members:
    :undoc-members:

nio.exceptions module
---------------------

.. automodule:: nio.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

nio.responses module
--------------------

.. automodule:: nio.responses
    :members:
    :undoc-members:

nio.rooms module
----------------

.. automodule:: nio.rooms
    :members:
    :undoc-members:
